export default {
    "message": "Cannot use 'await' as identifier inside an async function",
    "column": 9,
    "index": 8,
    "lineNumber": 1
}
